<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation> Informazioni su Boomaga</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Riconoscimenti</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Versione: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga fornisce una stampante virtuale per CUPS. Questa può essere usata per l&apos;anteprima di stampa o per la stampa di libretti.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Copyright: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Homepage: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Licenza: %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Se sei interessato a lavorare con il nostro team di sviluppo, &lt;a %1&gt;unisciti a noi&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Un ringraziamento speciale a:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Se desideri aiutare a tradurre, saremo felici di vederti nel nostro team di traduzione su &lt;a %1&gt;server Transifex&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Boomaga è sviluppato dal Team &lt;a %1&gt;Boomaga e dai  contributori&lt;/a&gt; su GitHub.</translation>
    </message>
</context>
<context>
    <name>BooFile</name>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Non posso scrivere nel file &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Dividi i tuoi lunghi fascicoli in sotto-fascicoli più piccoli per la stampa.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Stampa come sotto-fascicoli</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Numero massimo di fogli nel tuo sotto-fascicolo.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Fogli per sotto-fascicolo:</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Salva automaticamente i tuoi lavori di stampa ogni volta che stampi.</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Salva automaticamente le sessioni recenti</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>Consenti margini negativi per le pagine:</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Seleziona la cartella per i lavori di stampa salvati.</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Cartella per le sessioni salvate:</translation>
    </message>
    <message>
        <source>Right-to-left direction</source>
        <translation>Direzione da destra a sinistra</translation>
    </message>
</context>
<context>
    <name>CupsBooFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato, oppure il file è stato danneggiato.</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Stampa in PDF</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>File di output:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Meta info</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Autore:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Il nome della persona che ha creato il documento.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Oggetto:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>L&apos;oggetto del documento.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Parole chiave associate al documento.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Parole chiave:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>File PDF (*.pdf);;Tutti i file (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Sovrascrivere il file?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Un file con nome &quot;%1&quot; esiste già.
Sei sicuro di volerlo sovracrivere?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Il titolo del documento.</translation>
    </message>
</context>
<context>
    <name>InFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato, oppure il file è stato danneggiato.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 pagine</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferenze</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Disposizione</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>su 1</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>su 2</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Libretto</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Stampa su entrambi i lati di un foglio.</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Due-lati</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Lavori di stampa</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Stampante</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Configura...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Stampa</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Stampa e Chiudi</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Prossimo foglio</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Foglio precedente</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>A proposito di Boomaga</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v di %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Stampare tutte le pagine su %1.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Stampare le pagine dispari su %1.&lt;p&gt;Quando ha terminato, girare le pagine, inserirle nella stampante&lt;br&gt;e fare clic sul pulsante Continua.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Stampare le pagine pari su %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 pagine</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 pagina</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 fogli</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 foglio</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Foglio %1 di %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Inserisci una pagina vuota dopo questa pagina</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Eliminare questa pagina</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Annulla eliminazione</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Inserisci una pagina vuota prima di questa pagina</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Salva il progetto</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Salva come...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Salva il progetto con un nuovo nome</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Apri...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Apri un progetto esistente</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Pagina %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>File Boomaga (*.boo);;Tutti i file (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Progetto salvato con successo.</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Tutti i file supportati (*.pdf *.boo);;File Boomaga (*.boo);;File PDF (*.pdf);;Tutti i file (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 in orizzontale</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 in verticale</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 in orizzontale</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 in verticale</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Inizia un nuovo libretto da questa pagina</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Non iniziare un nuovo libretto da questa pagina</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Ruotare la pagina verso sinistra</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Ruotare la pagina verso destra</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Rinominare il lavoro di stampa</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Ruotare il lavoro di stampa verso sinistra</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Ruotare il lavoro di stampa verso destra</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Nome del lavoro di stampa:</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Esportare il progetto in PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Clonare un lavoro di stampa...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Clonare un lavoro di stampa</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Numero di copie:</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Stampare con opzioni...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Selezionare il numero di copie prima di stampare.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Sotto-fascicoli</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Annulla eliminazione pagina</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Pagina %1 di %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>File recenti</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>&amp;Modifica pagina</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>Modifica &amp;lavoro di stampa</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>&amp;Esporta in PDF...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Cancella le pagine fino alla fine del lavoro di stampa</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Cancella il lavoro di stampa corrente</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Auto salvataggio</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Non posso creare la cartella &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2: Pagina %3</translation>
    </message>
</context>
<context>
    <name>PostScriptFile</name>
    <message>
        <source>Converting PostScript to PDF</source>
        <comment>Progressbar text</comment>
        <translation>Conversione di PostScript in PDF</translation>
    </message>
    <message>
        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
        <translation>Non riesco ad avviare il convertitore gs: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Stampare il documento</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Numero di copie:</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Fascicola copie:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Margini (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Destro:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>In basso:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Interno:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Sinistro:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>In alto:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Disegnare il bordo</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Stampare in ordine inverso</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>La stampante ha il duplexer</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Manuale con inversione (adatto alla maggior parte delle stampanti)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Manuale senza inversione</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Preferenze di &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Profili</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Ripristinare impostazioni predefinite</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Profilo %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Modalità colore:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Forza la scala di grigio</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Forza il colore</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Stampa su entrambi i lati</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>Sfoglia sul lato corto</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>Sfoglia sul lato lungo</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Non riesco a scrivere sul file &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Non posso leggere dal file &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Non posso scrivere nel file &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Non riesco ad aprire il file &quot;% 1&quot; (nome del file vuoto)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Non posso aprire il file &quot;%1&quot; (File o cartella non esistenti)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Non posso aprire il file &quot;%1&quot; (Accesso negato)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Non posso aprire il file &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Senza titolo.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Sotto-fascicolo %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 pagine</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Non riesco a creare il file temporaneo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Non riesco a leggere il file &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Non riesco a scrivere sul file &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Non riesco a scrivere il file &quot;%1&quot;</translation>
    </message>
</context>
</TS>